package testcase;

import java.io.Serializable;
import java.util.Locale;
import java.util.Set;

import javax.ejb.Stateless;
import javax.validation.ConstraintViolation;
import javax.validation.MessageInterpolator;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.groups.Default;

@Stateless
public class Customermanagement implements Serializable{
	private static final long serialVersionUID = 870048022184554322L;

	public void createCustomer(Customer customer) {
		final ValidatorFactory validatorFactory = Validation.buildDefaultValidatorFactory();
		final MessageInterpolator interpolator = validatorFactory.getMessageInterpolator();
		final Locale locale = Locale.getDefault();
		
		final MessageInterpolator localeInterpolator = new LocaleSpecificMessageInterpolator(interpolator, locale);
		final Validator validator = validatorFactory.usingContext()
                                                    .messageInterpolator(localeInterpolator)
                                                    .getValidator();
		
		final Set<ConstraintViolation<Customer>> violations = validator.validate(customer, Default.class);
		
		if (violations != null && !violations.isEmpty()) {
			System.out.println(">>> Violations: " + violations);
		}
		else {
			System.out.println(">>> Customer: " + customer);
		}
	}
	
	public static class LocaleSpecificMessageInterpolator implements MessageInterpolator {
		private final MessageInterpolator interpolator;
		private final Locale locale;

		public LocaleSpecificMessageInterpolator(MessageInterpolator interpolator, Locale locale) {
			this.locale = locale;
			this.interpolator = interpolator;
		}

		@Override
		public String interpolate(String message, Context context) {
			final String resultMessage = interpolator.interpolate(message, context, locale);
			return resultMessage;
		}

		@Override
		public String interpolate(String message, Context context, Locale loc) {
			return interpolator.interpolate(message, context, loc);
		}
	}

}
